import request from '@/utils/request'

// 查询部门列表
export function baseInfoDepartment(query) {
  return request({
    url: '/business/per/baseInfo/department',
    method: 'get',
    params: query
  })
}

// 查询区域列表
export function baseInfoArea(query) {
  return request({
    url: '/business/per/baseInfo/area',
    method: 'get',
    params: query
  })
}

// 查询分站列表
export function baseInfoStation(query) {
  return request({
    url: '/business/per/baseInfo/station',
    method: 'get',
    params: query
  })
}

// 查询工种列表
export function baseInfoWorkType(query) {
  return request({
    url: '/business/per/baseInfo/workType',
    method: 'get',
    params: query
  })
}

// 查询职务列表
export function baseInfoPosition(query) {
  return request({
    url: '/business/per/baseInfo/position',
    method: 'get',
    params: query
  })
}

// 查询卡号列表
export function baseInfoCardNumber(query) {
  return request({
    url: '/business/per/baseInfo/carNumber',
    method: 'get',
    params: query
  })
}

//获取电站名称
export function eleGetSubstationName(query) {
  return request({
    url: '/business/ele/getSubstationName',
    method: 'get',
    params: query
  })
}

//获取电箱名称
export function eleGetEleboxName(query) {
  return request({
    url: '/business/ele/getEleboxName',
    method: 'get',
    params: query
  })
}
//获取电箱参数名称
export function eleGetEleboxParameter(query) {
  return request({
    url: '/business/ele/getEleboxParameter',
    method: 'get',
    params: query
  })
}

//环境监测检测项名称
export function typeNameList(query) {
  return request({
    url: '/business/real/typeList',
    method: 'get',
    params: query
  })
}

//排水系统设备类型
export function draDeviceName(query) {
  return request({
    url: '/business/dra/base/deviceName',
    method: 'get',
    params: query
  })
}

//风机系统风机名称下拉
export function fanDeviceName(query) {
  return request({
    url: '/business/fan/base/deviceName',
    method: 'get',
    params: query
  })
}